@@ -58,6 +58,21 @@ function activate_link (href, target) {
 
 }
 
+function open_popup_menu (type) {
+
+	var oPopup = window.createPopup ();
+	var div = document.getElementById ('vert_menu_' + type);
+	var table = document.getElementById ('vert_menu_table_' + type);
+	
+	var w = table.offsetWidth;
+	var h = table.offsetHeight;
+	
+	oPopup.document.body.innerHTML = div.innerHTML;												
+	oPopup.show (-9, 17, w, h, document.getElementById ('main_menu_' + type));
+	
+}
+
+
 function setVisible (id, isVisible) { 
 	document.getElementById (id).style.display = isVisible ? 'block' : 'none'
 };
